Imagenet2012Corrupted is a dataset generated by adding common corruptions to the
images in the ImageNet dataset. In the original paper, there are 15 + 4
different corruptions, and each has 5 levels of severity. We also implement the
4 extra corruptions gaussian blur, saturate, spatter, and speckle noise. The
randomness is fixed so that regeneration is deterministic.
